pub struct VcsOpts {
pub allow_no_vcs: bool,
pub allow_dirty: bool,
pub allow_staged: bool,
}Fields
allow_no_vcs: boolFix code even if a VCS was not detected
allow_dirty: boolFix code even if the working directory is dirty or has staged changes
allow_staged: boolFix code even if the working directory has staged changes
Implementations